@@ -4,15 +4,11 @@ from typing import BinaryIO
 from tempfile import mkstemp
 from pathlib import Path
 import zlib
-from contextlib import ExitStack
 import os
 import csv
 from io import StringIO
 from subprocess import run, DEVNULL
-try:
-    import ujson as json # type: ignore
-except ImportError:
-    import json
+import json
 
 try:
     from importlib.resources import files
@@ -118,7 +114,7 @@ class ZiptzBuildHook(BuildHookInterface):
         }
 
         with output.path.open('w') as out:
-            json.write(out, payload)
+            json.dump(payload, out, separators=(',', ':'))
 
         self.__files.append(output)
         build_data['force_include'][output.name] = dest
